summaryrefslogtreecommitdiffstats
path: root/kttsd/kcmkttsmgr/kcmkttsmgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/kcmkttsmgr/kcmkttsmgr.h')
-rw-r--r--kttsd/kcmkttsmgr/kcmkttsmgr.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kttsd/kcmkttsmgr/kcmkttsmgr.h b/kttsd/kcmkttsmgr/kcmkttsmgr.h
index e95dc9c..ab7b818 100644
--- a/kttsd/kcmkttsmgr/kcmkttsmgr.h
+++ b/kttsd/kcmkttsmgr/kcmkttsmgr.h
@@ -39,7 +39,7 @@
class PlugInConf;
class KttsFilterConf;
-class KListViewItem;
+class TDEListViewItem;
class TDEAboutData;
class TDEConfig;
class TQPopupMenu;
@@ -272,10 +272,10 @@ class KCMKttsMgr :
void removeFilter( bool sbd );
/**
* Move an item in a KListView up or down.
*/
- void lowerItemPriority( KListView* lView );
- void higherItemPriority( KListView* lView );
+ void lowerItemPriority( TDEListView* lView );
+ void higherItemPriority( TDEListView* lView );
/**
* Count number of configured Filters with the specified plugin name.
@@ -272,10 +272,10 @@ class KCMKttsMgr :
void removeFilter( bool sbd );
/**
- * Move an item in a KListView up or down.
+ * Move an item in a TDEListView up or down.
*/